aboutsummaryrefslogtreecommitdiff
path: root/src/modules
diff options
context:
space:
mode:
authorLorenz Meier <lm@inf.ethz.ch>2013-07-26 18:24:37 +0200
committerLorenz Meier <lm@inf.ethz.ch>2013-07-26 18:24:37 +0200
commit95dde5f1bed21d1a36a065c94c961a8f216a10b0 (patch)
tree8e96488a1004bb9ef3d86336b49be7b303dd2c0d /src/modules
parenta8ac56b9e5eb8c1501ea592b4417aa8becd7236c (diff)
downloadpx4-firmware-95dde5f1bed21d1a36a065c94c961a8f216a10b0.tar.gz
px4-firmware-95dde5f1bed21d1a36a065c94c961a8f216a10b0.tar.bz2
px4-firmware-95dde5f1bed21d1a36a065c94c961a8f216a10b0.zip
Implemented config command, fixed a number range set / get issues for some sensor drivers, fixed gyro calibration
Diffstat (limited to 'src/modules')
-rw-r--r--src/modules/commander/commander.c10
1 files changed, 8 insertions, 2 deletions
diff --git a/src/modules/commander/commander.c b/src/modules/commander/commander.c
index 8e5e36712..e9d1f3954 100644
--- a/src/modules/commander/commander.c
+++ b/src/modules/commander/commander.c
@@ -587,6 +587,8 @@ void do_gyro_calibration(int status_pub, struct vehicle_status_s *status)
close(fd);
+ int errcount = 0;
+
while (calibration_counter < calibration_count) {
/* wait blocking for new data */
@@ -602,8 +604,12 @@ void do_gyro_calibration(int status_pub, struct vehicle_status_s *status)
calibration_counter++;
} else if (poll_ret == 0) {
- /* any poll failure for 1s is a reason to abort */
- mavlink_log_info(mavlink_fd, "gyro calibration aborted, retry");
+ errcount++;
+ }
+
+ if (errcount > 1000) {
+ /* any persisting poll error is a reason to abort */
+ mavlink_log_info(mavlink_fd, "permanent gyro error, aborted.");
return;
}
}